--------------------------------------------------------------------------------
-- CREATE TABLE
CREATE TABLE log_dxt_udat (
    action                         VARCHAR2(1)
  , rec_date                       DATE
  , rec_user                       VARCHAR2(240)
  , user_name                      VARCHAR2(240)
  , data_id                        VARCHAR2(240)
  , comments                       VARCHAR2(2000)
);

COMMENT ON TABLE  log_dxt_udat IS '[U[pf[^(LOG)';
COMMENT ON COLUMN log_dxt_udat.action                         IS 'ANV';
COMMENT ON COLUMN log_dxt_udat.rec_date                       IS 'XV';
COMMENT ON COLUMN log_dxt_udat.rec_user                       IS 'XV';
COMMENT ON COLUMN log_dxt_udat.user_name                      IS '[U[';
COMMENT ON COLUMN log_dxt_udat.data_id                        IS 'f[^ID';
COMMENT ON COLUMN log_dxt_udat.comments                       IS 'Rg';

--------------------------------------------------------------------------------
-- CREATE TRIGGER
CREATE OR REPLACE TRIGGER log_dxt_udat
AFTER INSERT OR DELETE OR UPDATE ON dxt_udat
FOR EACH ROW
DECLARE
    rec_log log_dxt_udat %ROWTYPE;
BEGIN
    --
    rec_log := NULL;
    --
    IF INSERTING THEN
        rec_log.action := 'I';
    ELSIF UPDATING THEN
        rec_log.action := 'U';
    ELSIF DELETING THEN
        rec_log.action := 'D';
    END IF;
    --
    IF INSERTING OR UPDATING THEN
        rec_log.rec_date  := :NEW.rec_date  ;
        rec_log.rec_user  := :NEW.rec_user  ;
        rec_log.user_name := :NEW.user_name ;
        rec_log.data_id   := :NEW.data_id   ;
        rec_log.comments  := :NEW.comments  ;
    ELSE
        rec_log.rec_date  := SYSDATE        ;
        rec_log.rec_user  := :OLD.rec_user  ;
        rec_log.user_name := :OLD.user_name ;
        rec_log.data_id   := :OLD.data_id   ;
        rec_log.comments  := :OLD.comments  ;
    END IF;
    --
    INSERT INTO log_dxt_udat VALUES rec_log;
    --
END;
/
