--------------------------------------------------------------------------------
-- CREATE TABLE
CREATE TABLE log_dxt_user (
    action                         VARCHAR2(1)
  , rec_date                       DATE
  , rec_user                       VARCHAR2(240)
  , user_name                      VARCHAR2(240)
  , user_cd                        VARCHAR2(480)
  , user_pass                      VARCHAR2(64)
  , auth_cls                       NUMBER(1,0)
  , admin_cls                      NUMBER(1,0)
  , comments                       VARCHAR2(2000)
);

COMMENT ON TABLE  log_dxt_user IS '[U[(LOG)';
COMMENT ON COLUMN log_dxt_user.action                         IS 'ANV';
COMMENT ON COLUMN log_dxt_user.rec_date                       IS 'XV';
COMMENT ON COLUMN log_dxt_user.rec_user                       IS 'XV';
COMMENT ON COLUMN log_dxt_user.user_name                      IS '[U[';
COMMENT ON COLUMN log_dxt_user.user_cd                        IS '[U[R[h';
COMMENT ON COLUMN log_dxt_user.user_pass                      IS 'pX[h(SHA256)';
COMMENT ON COLUMN log_dxt_user.auth_cls                       IS 'F؋敪i1:ƎF؁A2:ADF؁j';
COMMENT ON COLUMN log_dxt_user.admin_cls                      IS 'Ǘҋ敪i1:ǗҁA2:Ǘҁj';
COMMENT ON COLUMN log_dxt_user.comments                       IS 'Rg';

--------------------------------------------------------------------------------
-- CREATE TRIGGER
CREATE OR REPLACE TRIGGER log_dxt_user
AFTER INSERT OR DELETE OR UPDATE ON dxt_user
FOR EACH ROW
DECLARE
    rec_log log_dxt_user %ROWTYPE;
BEGIN
    --
    rec_log := NULL;
    --
    IF INSERTING THEN
        rec_log.action := 'I';
    ELSIF UPDATING THEN
        rec_log.action := 'U';
    ELSIF DELETING THEN
        rec_log.action := 'D';
    END IF;
    --
    IF INSERTING OR UPDATING THEN
        rec_log.rec_date  := :NEW.rec_date  ;
        rec_log.rec_user  := :NEW.rec_user  ;
        rec_log.user_name := :NEW.user_name ;
        rec_log.user_cd   := :NEW.user_cd   ;
        rec_log.user_pass := :NEW.user_pass ;
        rec_log.auth_cls  := :NEW.auth_cls  ;
        rec_log.admin_cls := :NEW.admin_cls ;
        rec_log.comments  := :NEW.comments  ;
    ELSE
        rec_log.rec_date  := SYSDATE        ;
        rec_log.rec_user  := :OLD.rec_user  ;
        rec_log.user_name := :OLD.user_name ;
        rec_log.user_cd   := :OLD.user_cd   ;
        rec_log.user_pass := :OLD.user_pass ;
        rec_log.auth_cls  := :OLD.auth_cls  ;
        rec_log.admin_cls := :OLD.admin_cls ;
        rec_log.comments  := :OLD.comments  ;
    END IF;
    --
    INSERT INTO log_dxt_user VALUES rec_log;
    --
END;
/
